Module open

Module open 

Structs

CodeOpener
Opener implementation that supports VSCode.
DefaultOpener
Opener implementation that handles all editors and disregards line numbers.
EmacsOpener
Opener implementation that supports emacs.
LessOpener
Opener implementation that supports less/more.
SublimeOpener
Opener implementation that supports subl, Sublime Text’s CLI tool.
ViOpener
Opener implementation that supports vi/vim/nvim.
XedOpener
Opener implementation that supports xed, Xcode’s text editor CLI tool.

Traits

Opener
Facilitates the opening of a file with a provided editor.

Functions

open
Attempts to open a file with a specified editor.